@@ -12,6 +12,7 @@ import larch
 
 from wxutils import (MenuItem, Font, Button, Choice)
 
+from .gui_utils import LarchWxApp
 from .readlinetextctrl import ReadlineTextCtrl
 from .larchfilling import Filling
 from .columnframe import ColumnDataFileFrame
@@ -39,7 +40,7 @@ class LarchWxShell(object):
                  prompt=None, historyfile=None, output=None, input=None):
         self._larch = _larch
         self.textstyle = None
-
+        self.parent = wxparent
         self.prompt = prompt
         self.input  = input
         self.output = output
@@ -50,9 +51,6 @@ class LarchWxShell(object):
             self._larch.run_init_scripts()
         self.writer  = self._larch.writer
         self.symtable = self._larch.symtable
-        # if self.output is not None:
-        #    self.encoding = sys.stdout.encoding
-        #    sys.stdout = self
 
         self.objtree = wxparent.objtree
 
@@ -75,10 +73,10 @@ class LarchWxShell(object):
             self.textstyle = wx.TextAttr('black', bgcol, sfont)
 
         self.SetPrompt(True)
-        self.flush_timer = wx.Timer(wxparent)
-        self.needs_flush = True
-        wxparent.Bind(wx.EVT_TIMER, self.onFlushTimer, self.flush_timer)
-        self.flush_timer.Start(500)
+        # self.flush_timer = wx.Timer(wxparent)
+        # self.needs_flush = True
+        # wxparent.Bind(wx.EVT_TIMER, self.onFlushTimer, self.flush_timer)
+        # wx.CallAfter(self.flush_timer.Start, 500)
 
     def onUpdate(self, event=None):
         symtable = self.symtable
@@ -131,7 +129,8 @@ class LarchWxShell(object):
             self.output.WriteText(text)
             pos1 = self.output.GetLastPosition()
             self.output.SetStyle(pos0, pos1, self.textstyle)
-            self.output.EmulateKeyPress(wx.KeyEvent())
+            self.output.SetInsertionPoint(pos1)
+            self.output.Refresh()
             self.input.SetFocus()
 
     def flush(self, *args):
@@ -159,7 +158,7 @@ class LarchWxShell(object):
             return
         else:
             if add_history:
-                self.input.AddToHistory(text)
+                self.parent.AddToHistory(text)
                 self.write("%s\n" % text)
             ret = self._larch.eval(text, add_history=add_history)
             if self._larch.error:
@@ -204,20 +203,28 @@ class LarchPanel(wx.Panel):
 
         splitter.SplitHorizontally(self.objtree, self.output, 0.5)
 
-        ipanel = wx.Panel(self, -1)
+        ipanel = wx.Panel(self)
 
-        self.prompt = wx.StaticText(ipanel, -1, 'Larch>', size=(65,-1),
+        self.prompt = wx.StaticText(ipanel, label='Larch>', size=(65,-1),
                                     style=wx.ALIGN_CENTER|wx.ALIGN_RIGHT)
 
-        self.input = ReadlineTextCtrl(ipanel, -1,  '', size=(525,-1),
-                                      historyfile=historyfile,
-                                      style=wx.ALIGN_LEFT|wx.TE_PROCESS_ENTER)
+        self.input = wx.TextCtrl(ipanel, value='', size=(525,-1),
+                                 style=wx.TE_LEFT|wx.TE_PROCESS_ENTER)
 
+        # self.input = ReadlineTextCtrl(ipanel, value='', size=(525, -1),
+        #                               historyfile=historyfile,
+        #                              style=wx.TE_LEFT|wx.TE_PROCESS_ENTER)
         self.input.Bind(wx.EVT_TEXT_ENTER, self.onText)
+        if sys.platform == 'darwin':
+            self.input.Bind(wx.EVT_KEY_UP,  self.onChar)
+        else:
+            self.input.Bind(wx.EVT_CHAR,  self.onChar)
+
+        self.hist_buff = []
+        self.hist_mark = 0
+        
         isizer = wx.BoxSizer(wx.HORIZONTAL)
         isizer.Add(self.prompt,  0, wx.BOTTOM|wx.CENTER)
-
-        ## isizer.Add(self.input,   1, wx.ALIGN_LEFT|wx.ALIGN_CENTER|wx.EXPAND)
         isizer.Add(self.input,   1, wx.ALIGN_LEFT|wx.EXPAND)
 
         ipanel.SetSizer(isizer)
@@ -237,12 +244,14 @@ class LarchPanel(wx.Panel):
                                        input  = self.input)
 
         self.objtree.SetRootObject(self.larchshell.symtable)
+        root = self.objtree.tree.GetRootItem()
+        self.objtree.tree.Expand(root)
+
+    def write_banner(self):
         self.larchshell.set_textstyle('text2')
         self.larchshell.write(make_banner([wx]))
         self.larchshell.write("\n  \n")
         self.larchshell.set_textstyle('text')
-        root = self.objtree.tree.GetRootItem()
-        self.objtree.tree.Expand(root)
 
     def update(self):
         self.objtree.onRefresh()
@@ -255,6 +264,40 @@ class LarchPanel(wx.Panel):
         else:
             wx.CallAfter(self.larchshell.eval, text)
 
+    def onChar(self, event=None):
+        key = event.GetKeyCode()
+        entry  = self.input.GetValue().strip()
+        pos = self.input.GetSelection()
+        ctrl = event.ControlDown()
+
+        # really, the order here is important:
+        # 1. return sends to ValidateEntry
+        if key == wx.WXK_RETURN and len(entry) > 0:
+            pass
+        if key == wx.WXK_UP:
+            self.hist_mark = max(0, self.hist_mark-1)
+            try:
+                self.input.SetValue(self.hist_buff[self.hist_mark])
+                self.input.SetInsertionPointEnd()
+            except:
+                pass
+        elif key == wx.WXK_DOWN:
+            self.hist_mark += 1
+            if self.hist_mark >= len(self.hist_buff):
+                self.input.SetValue('')
+            else:
+                self.input.SetValue(self.hist_buff[self.hist_mark])
+                self.input.SetInsertionPointEnd()
+        event.Skip()
+
+    def AddToHistory(self, text=''):
+        for tline in text.split('\n'):
+            if len(tline.strip()) > 0:
+                self.hist_buff.append(tline)
+                self.hist_mark = len(self.hist_buff)
+        
+
+            
 class LarchFrame(wx.Frame):
     def __init__(self, parent=None, _larch=None, is_standalone=True,
                  historyfile='history_larchgui.lar', with_inspection=False,
@@ -302,7 +345,7 @@ class LarchFrame(wx.Frame):
         fico = os.path.join(larch.site_config.icondir, ICON_FILE)
         if os.path.exists(fico):
             self.SetIcon(wx.Icon(fico, wx.BITMAP_TYPE_ICO))
-
+        self.mainpanel.write_banner()
         if with_raise:
             self.Raise()
 
@@ -494,6 +537,7 @@ class LarchFrame(wx.Frame):
             self.SetStatusText("Wrote %s" % fout, 0)
         dlg.Destroy()
 
+       
     def onText(self, event=None):
         text =  event.GetString()
         self.larchshell.write("%s\n" % text)
@@ -501,7 +545,7 @@ class LarchFrame(wx.Frame):
         if text.lower() in ('quit', 'exit'):
             self.onExit()
         else:
-            self.input.AddToHistory(text)
+            self.panel.AddToHistory(text)
             wx.CallAfter(self.larchshell.eval, text)
 
 
@@ -558,14 +602,13 @@ class LarchFrame(wx.Frame):
             except:
                 pass
 
-
-class LarchApp(wx.App, wx.lib.mixins.inspection.InspectionMixin):
+class LarchApp(LarchWxApp):
     "simple app to wrap LarchFrame"
     def __init__(self, **kws):
-        wx.App.__init__(self, **kws)
+        LarchWxApp.__init__(self, **kws)
 
-    def OnInit(self):
-        frame = LarchFrame(exit_on_close=True, with_inspection=False)
+    def createApp(self):
+        frame = LarchFrame(exit_on_close=True, with_inspection=self.with_inspect)
         frame.Show()
         self.SetTopWindow(frame)
         return True
